@@ -1,5 +1,5 @@
 from .model import TrainTransformersNER
 from .model_prediction import TransformersNER
-from .get_dataset import get_dataset_ner, SHARED_NER_LABEL, VALID_DATASET
+from .get_dataset import get_dataset_ner, SHARED_NER_LABEL, VALID_DATASET, PANX as panx_language_list
 from .japanese_tokenizer import SudachiWrapper
 from .tokenizer import Transforms
